# ryca-django-grpc

.. image:: https://img.shields.io/pypi/v/ryca_django_grpc.svg
   :target: https://img.shields.io/pypi/v/ryca_django_grpc.svg

.. image:: https://readthedocs.org/projects/ryca_django_grpc/badge/?version=latest
   :target: https://readthedocs.org/projects/ryca_django_grpc/badge/?version=latest

.. image:: https://img.shields.io/pypi/pyversions/ryca_django_grpc
   :target: https://img.shields.io/pypi/pyversions/ryca_django_grpc

.. image:: https://img.shields.io/pypi/l/ryca_django_grpc
   :target: https://img.shields.io/pypi/l/ryca_django_grpc


Django gRPC framework is a toolkit for building gRPC services, inspired by django-grpc-framework.
